configurationtools.get_lilypond_version_string
==============================================

.. autofunction:: abjad.tools.configurationtools.get_lilypond_version_string.get_lilypond_version_string
